@@ -62,6 +62,12 @@ typedef struct _NetkTaskClass NetkTaskClass;
 
 #define N_SCREEN_CONNECTIONS 5
 
+#ifdef PANGO_ELLIPSIZE_END
+#define NETK_ELLIPSIZE_END PANGO_ELLIPSIZE_END
+#else
+#define NETK_ELLIPSIZE_END 3
+#endif
+
 typedef enum
 {
     NETK_TASK_CLASS_GROUP,
@@ -2237,9 +2243,14 @@ netk_task_create_widgets (NetkTask * task)
 
     if (task->tasklist->priv->show_label) {
         task->label = gtk_label_new (text);
+        gtk_misc_set_alignment (GTK_MISC (task->label), 0.5, 0.5);
+        if ((gtk_major_version == 2 && gtk_minor_version >= 6) || gtk_major_version > 2)
+        {
+            g_object_set (G_OBJECT (task->label), "ellipsize", NETK_ELLIPSIZE_END, NULL);
+        }
         gtk_widget_show (task->label);
         gtk_table_attach (GTK_TABLE (table),
-                      task->label, 1, 2, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
+                      task->label, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL, GTK_EXPAND, 0, 0);
     }
 
     gtk_container_add (GTK_CONTAINER (task->button), table);
