@@ -444,7 +444,7 @@ GtkWidget *xfce_app_menu_item_new_full(const gchar *label, const gchar *command,
  * xfce_app_menu_item_new_from_desktop_entry:
  * @entry: An #XfceDesktopEntry describing the menu item to create.
  * @show_icon: Sets whether or not to show an icon in the menu item.
- * @returns: A new #XfceAppMenuItem.
+ * @returns: A new #XfceAppMenuItem, or %NULL on error.
  *
  * Creates a new #XfceAppMenuItem using parameters from the application
  * specified in a #XfceDesktopEntry object. This has the effect of calling
@@ -487,6 +487,12 @@ xfce_app_menu_item_new_from_desktop_entry(XfceDesktopEntry *entry,
 		g_free(tmp);
 	}
 	app_menu_item->priv->name = name;
+	if(!g_utf8_validate(name, -1, NULL)) {
+		g_warning("XfceAppMenuItem: 'name' failed utf8 validation for .desktop file '%s'",
+				xfce_desktop_entry_get_file(entry));
+		gtk_widget_destroy(GTK_WIDGET(app_menu_item));
+		return NULL;
+	}
 	
 	accel_label = gtk_accel_label_new(app_menu_item->priv->name);
 	gtk_misc_set_alignment(GTK_MISC(accel_label), 0.0, 0.5);
@@ -512,6 +518,23 @@ xfce_app_menu_item_new_from_desktop_entry(XfceDesktopEntry *entry,
 		if((p=strchr(cmd, ' ')))
 			*p = 0;
 	}	
+        /* remove quotes around the command (yes, people do that!) */
+        if (cmd[0] == '"')
+        {
+            int i;
+
+            for (i = 1; cmd[i - 1] != '\0'; ++i)
+            {
+                if (cmd[i] != '"')
+                    cmd[i-1] = cmd[i];
+                else
+                {
+                    cmd[i-1] = cmd[i] = ' ';
+                    break;
+                }
+            }
+        }
+
 	app_menu_item->priv->command = xfce_expand_variables(cmd, NULL);
 	g_free(cmd);
 	
