@@ -203,11 +203,11 @@ static gchar *
 theme_name_to_dir(const gchar *base_path, const gchar *theme_name)
 {
 	GDir *dir;
-	gchar fullpath[PATH_MAX], *idx_theme_name;
-	
+	gchar fullpath[PATH_MAX], *idx_theme_name, *ret = NULL;
+	const gchar *file;
+    
 	dir = g_dir_open(base_path, 0, NULL);
 	if(dir) {
-		const gchar *file;
 		while((file = g_dir_read_name(dir))) {
 			g_snprintf(fullpath, PATH_MAX, "%s/%s/", base_path, file);
 			if(!g_file_test(fullpath, G_FILE_TEST_IS_DIR))
@@ -220,13 +220,15 @@ theme_name_to_dir(const gchar *base_path, const gchar *theme_name)
 			
 			if(!strcmp(theme_name, idx_theme_name)) {
 				g_free(idx_theme_name);
-				return g_strdup(file);
+				ret = g_strdup(file);
+				break;
 			} else
 				g_free(idx_theme_name);
-		}	
+		}
+		g_dir_close(dir);
 	}
 	
-	return NULL;
+	return ret;
 }
 
 static void
