@@ -41,6 +41,23 @@
 #include <gmodule.h>
 #include <libxfce4util/libxfce4util.h>
 
+#ifndef S_ISSOCK 
+# ifdef S_IFSOCK
+# define S_ISSOCK(x) ((x&S_IFMT)==S_IFSOCK)
+# else
+# define S_ISSOCK(x) FALSE
+# endif
+#else
+#endif
+
+#ifndef S_ISLNK
+# ifdef S_IFLNK
+# define S_ISLNK(x) ((x&S_IFMT)==S_IFLNK)
+# else
+# define S_ISLNK(x) FALSE
+# endif
+#endif
+
 /* include non installed headers */
 #include <xfce4-modules/headers/constants.h>
 #include <xfce4-modules/headers/mime.h>
@@ -239,7 +256,7 @@ compare_cache_info(void){
 	DBG("incorrect read of basesum");
 	return FALSE;
     }
-    TRACE("%d == %d",basefile_sum,get_cache_info());
+    TRACE("%d == %d",(int)basefile_sum,(int)get_cache_info());
     
     return (basefile_sum == get_cache_info());
 }
@@ -870,7 +887,7 @@ const gchar *mk_command_line(const gchar *command_fmt,const gchar *path,gboolean
     }
     TRACE("fmt=%s\n",fmt);
 
-    for (p=(gchar *)path;*p;p++){
+    if (*path != '"') for (p=(gchar *)path;*p;p++){
 	if ((*p>='A' && *p<='Z') || (*p>='a' && *p<='z') || (*p>='0' && *p<='9')) continue;
 	quoted=TRUE;
 	break;
