@@ -378,6 +378,7 @@ read_icon_directory(gchar *directory, theme_info_t *theme_info_p,
         if (!icon_info_p){
 	        icon_info_p = (icon_info_t *)malloc(sizeof(icon_info_t));
         } else {
+		while (icon_info_p->next)icon_info_p= icon_info_p->next;
 	        icon_info_p->next = (icon_info_t *)malloc(sizeof(icon_info_t));
 	        icon_info_p = icon_info_p->next;
         }
@@ -786,7 +787,7 @@ static long long get_basedir_sum(void){
 	    basedir_sum += st.st_mtime;
 	    basedir_sum += st.st_dev;
 	}
-	TRACE("summing %s (%d %d)",(gchar *)list->data,st.st_mtime,st.st_dev);
+	/*TRACE("summing %s (%d %d)",(gchar *)list->data,st.st_mtime,st.st_dev);*/
     }
    basedir_sum +=SERIAL;
    return basedir_sum;
